@@ -15,14 +15,14 @@ def get_project_root() -> Path:
     """Project root is the parent of the config directory. Probably..."""
     p = Path.cwd()
     while len(p.parts) > 1:
-        if (p / "config").exists():
+        if (p / ".gama").exists():
             return p
         else:
             p = p.parent
 
     click.echo(
         click.style(
-            "Are you in a GAMA project? Have you ran `gama_cli vessel configure` or `gama_cli gs configure`?",
+            "Are you in a GAMA project? Have you ran `gama_cli vessel configure` or `gama_cli gs configure`? No `.gama` directory found.",
             fg="yellow",
         )
     )
